/**
 * osc VPT receive example by hc gilje
 * VPT website http://hcgilje.wordpress.com/vpt
 * based on oscP5sendreceive nexample + oscp5 documentatio by andreas schlegel
 * example shows how to send and receive osc messages.
 * oscP5 website at http://www.sojamo.de/oscP5
 */
 
import oscP5.*;
import netP5.*;
  
OscP5 oscP5;
NetAddress myRemoteLocation;

void setup() {
  size(400,400);
  frameRate(25);
  /* start oscP5, listening for incoming messages at port 6667 */
  oscP5 = new OscP5(this,6667);
  
  /* myRemoteLocation is a NetAddress. a NetAddress takes 2 parameters,
   * an ip address and a port number. myRemoteLocation is used as parameter in
   * oscP5.send() when sending osc packets to another computer, device, 
   * application. usage see below. for testing purposes the listening port
   * and the port of the remote location address are the same, hence you will
   * send messages back to this sketch.
   */
  myRemoteLocation = new NetAddress("10.0.0.2",6666);
}


void draw() {
  background(0);  
}

void mousePressed() {
  /* in the following different ways of creating osc messages are shown by example */
  OscMessage myMessage = new OscMessage("/test");
  
  myMessage.add(12345); /* add an int to the osc message */

  /* send the message */
  oscP5.send(myMessage, myRemoteLocation); 
}


/* incoming osc message are forwarded to the oscEvent method. */
void oscEvent(OscMessage theOscMessage) {
  /* print the address pattern and the typetag of the received OscMessage */
  print("### received an osc message.");
 // print(" addrpattern: "+theOscMessage.addrPattern());
  //println(" typetag: "+theOscMessage.typetag());
  theOscMessage.print();
  print("osc address ");
  println(theOscMessage.addrPattern());
  print("osc arguments ");
  println(theOscMessage.arguments());
  print("osc typetag ");
  println(theOscMessage.typetag());
  
  //checks typetag of the incoming osc message
  if (theOscMessage.checkTypetag("i")==true) {
    print("integer: ");
    println(theOscMessage.get(0).intValue());
  } else if (theOscMessage.checkTypetag("f")==true) {
    print("float: ");
    println(theOscMessage.get(0).floatValue());
  } else if(theOscMessage.checkTypetag("s")==true) {
    print("string: ");
    println(theOscMessage.get(0).stringValue());
  }
}
